/* This file was generated by syncqt. */
#ifndef QT_QTQUICK3DPHYSICSHELPERS_VERSION_H
#define QT_QTQUICK3DPHYSICSHELPERS_VERSION_H

#define QTQUICK3DPHYSICSHELPERS_VERSION_STR "6.6.2"

#define QTQUICK3DPHYSICSHELPERS_VERSION 0x060602

#endif // QT_QTQUICK3DPHYSICSHELPERS_VERSION_H
